Core
====

Core routines of the EQcorrscan project.

API-docs
--------

.. toctree::
   :maxdepth: 1

   submodules/core.lag_calc
   submodules/core.match_filter
   submodules/core.subspace
   submodules/core.template_gen
